## Dataset Attribution
This dataset was created by Wan et al and is licensed under the Creative Commons Attribution 4.0 International.

- Original Source: [aclanthology.org](https://aclanthology.org/2023.findings-emnlp.243/)
- License: [https://creativecommons.org/licenses/by/4.0/](https://creativecommons.org/licenses/by/4.0/)
- Changes Made: We extracted the lexicons from Table 20. We filled in the words
that had asterisks with appropriate suffixes. Ability, Standout,
Leadership, Masculine, and Agentic lexicons are considered as male. Feminine,
Communal, and Personal are considered female. This reflects both the
warmth-competence stereotype content model that describes men as competent
and women as warm, but also other gender stereotypes. We have not used the
Professional lexicon because we use the lexicon in business communication, where
professional words are too common.